@@ -39,7 +39,7 @@ copy_color (GtkWidget *widget, GdkEvent  *event, MateColorSelectionDialog *color
     GdkColor color;
     gchar *color_string;
 
-    mate_color_selection_get_current_color (color_dialog->colorsel, &color);
+    mate_color_selection_get_current_color (MATE_COLOR_SELECTION (color_dialog->colorsel), &color);
     g_object_get (color_dialog->colorsel, "hex-string", &color_string, NULL);
 
     gtk_clipboard_set_text (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD), color_string, -1);
@@ -52,6 +52,7 @@ int
 main (int argc, char **argv)
 {
     GtkWidget *color_dialog = NULL;
+    GtkWidget *color_selection;
     GtkWidget *widget;
 
     mate_gettext (GETTEXT_PACKAGE, LOCALE_DIR, "UTF-8");
@@ -61,17 +62,18 @@ main (int argc, char **argv)
     gtk_window_set_default_icon_name ("gtk-select-color");
 
     color_dialog = mate_color_selection_dialog_new (_("MATE Color Selection"));
-    mate_color_selection_set_has_palette (MATE_COLOR_SELECTION_DIALOG (color_dialog)->colorsel, TRUE);
+    color_selection = MATE_COLOR_SELECTION_DIALOG (color_dialog)->colorsel;
+    mate_color_selection_set_has_palette (MATE_COLOR_SELECTION (color_selection), TRUE);
 
     /* quit signal */
     g_signal_connect (color_dialog, "destroy", gtk_main_quit, NULL);
 
     widget = gtk_button_new_from_stock (GTK_STOCK_COPY);
-    gtk_container_add (gtk_dialog_get_action_area (GTK_DIALOG (color_dialog)), widget);
+    gtk_container_add (GTK_CONTAINER (gtk_dialog_get_action_area (GTK_DIALOG (color_dialog))), widget);
     g_signal_connect (widget, "button-release-event", copy_color, color_dialog);
 
     widget = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
-    gtk_container_add (gtk_dialog_get_action_area (GTK_DIALOG (color_dialog)), widget);
+    gtk_container_add (GTK_CONTAINER (gtk_dialog_get_action_area (GTK_DIALOG (color_dialog))), widget);
     g_signal_connect (widget, "button-release-event", gtk_main_quit, NULL);
 
     gtk_widget_show_all (color_dialog);
